# -*- coding: utf-8 -*-


def format_status(rows_length=None, cursor=None):
    return rows_status(rows_length) + statistics(cursor)

def rows_status(rows_length):
    if rows_length:
        return '%d row%s in set' % (rows_length, '' if rows_length == 1 else 's')
    else:
        return 'Query OK'

def statistics(cursor):
    if cursor:
        # Most regions are $5 per TB: https://aws.amazon.com/athena/pricing/
        approx_cost = cursor.data_scanned_in_bytes / (1024 ** 4) * 5

        return '\nExecution time: %d ms, Data scanned: %s, Approximate cost: $%.2f' % (
                cursor.engine_execution_time_in_millis,
                humanize_size(cursor.data_scanned_in_bytes),
                approx_cost)
    else:
        return ''

def humanize_size(num_bytes):
    suffixes = ['B', 'KB', 'MB', 'GB', 'TB']

    suffix_index = 0
    while num_bytes >= 1024 and suffix_index < len(suffixes) - 1:
        num_bytes /= 1024.0
        suffix_index += 1

    num = ('%.2f' % num_bytes).rstrip('0').rstrip('.')
    return '%s %s' % (num, suffixes[suffix_index])



# -*- coding: utf-8 -*-


from collections import namedtuple
from athenacli.packages.format_utils import format_status, humanize_size


def test_format_status_plural():
    assert format_status(rows_length=1) == "1 row in set"
    assert format_status(rows_length=2) == "2 rows in set"

def test_format_status_no_results():
    assert format_status(rows_length=None) == "Query OK"

def test_format_status_with_stats():
    FakeCursor = namedtuple("FakeCursor", ["engine_execution_time_in_millis", "data_scanned_in_bytes"])

    assert format_status(rows_length=1, cursor=FakeCursor(10, 12345678900)) == "1 row in set\nExecution time: 10 ms, Data scanned: 11.5 GB, Approximate cost: $0.06"
    assert format_status(rows_length=2, cursor=FakeCursor(1000, 1234)) == "2 rows in set\nExecution time: 1000 ms, Data scanned: 1.21 KB, Approximate cost: $0.00"

def test_humanize_size():
    assert humanize_size(20) == "20 B"
    assert humanize_size(2000) == "1.95 KB"
    assert humanize_size(200000) == "195.31 KB"
    assert humanize_size(20000000) == "19.07 MB"
    assert humanize_size(200000000000) == "186.26 GB"
